@@ -1,9 +1,12 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
+import subprocess
 import gi
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, CDesktopEnums
-from GSettingsWidgets import *
+
+from gi.repository import Gtk
+from SettingsWidgets import SidePage, GSettingsDependencySwitch, DependencyCheckInstallButton, GSettingsSoundFileChooser
+from xapp.GSettingsWidgets import *
 
 DPI_FACTOR_LARGE         = 1.25
 DPI_FACTOR_NORMAL        = 1.0
@@ -30,7 +33,7 @@ class Module:
 
     def on_module_selected(self):
         if not self.loaded:
-            print "Loading Accessibility module"
+            print("Loading Accessibility module")
 
             self.iface_settings = Gio.Settings(schema_id="org.cinnamon.desktop.interface")
             self.wm_settings = Gio.Settings(schema_id="org.cinnamon.desktop.wm.preferences");
@@ -65,13 +68,19 @@ class Module:
             settings.add_row(switch)
 
             switch = GSettingsDependencySwitch(_("Screen reader"),
-                                     "org.cinnamon.desktop.a11y.applications",
-                                     "screen-reader-enabled",
-                                     None,
-                                     ["orca"],
-                                     ["gnome-orca"])
+                                               "org.cinnamon.desktop.a11y.applications",
+                                               "screen-reader-enabled",
+                                               None,
+                                               ["orca"],
+                                               ["gnome-orca"])
             settings.add_row(switch)
 
+            def config_orca(button):
+                subprocess.Popen(['orca', '--setup'])
+
+            button = Button(_("Configure screen reader"), config_orca)
+            settings.add_reveal_row(button, "org.cinnamon.desktop.a11y.applications", "screen-reader-enabled")
+
 # Desktop Zoom
 
             settings = page.add_section(_("Desktop Zoom"))
@@ -82,7 +91,7 @@ class Module:
             spin = GSettingsSpinButton(_("Magnification"), "org.cinnamon.desktop.a11y.magnifier", "mag-factor", None, 1.0, 15.0, step=0.5)
             settings.add_reveal_row(spin, "org.cinnamon.desktop.a11y.applications", "screen-magnifier-enabled")
 
-            zoom_key_options = [["", _("Disabled")], ["<Alt>", "<Alt>"],["<Super>", "<Super>"],["<Control>", "<Control>"]]
+            zoom_key_options = [["", _("Disabled")], ["<Alt>", "<Alt>"],["<Super>", "<Super>"],["<Control>", "<Control>"], ["<Shift>", "<Shift>"]]
             widget = GSettingsComboBox(_("Mouse wheel modifier"), "org.cinnamon.desktop.wm.preferences", "mouse-button-zoom-modifier", zoom_key_options)
             widget.set_tooltip_text(_("While this modifier is pressed, mouse scrolling will increase or decrease zoom."))
             settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-magnifier-enabled")
@@ -148,13 +157,26 @@ class Module:
 
             settings.add_row(switch)
 
-            keyboard_type_options = [["touch",     _("Touch")],
+            keyboard_type_options = [["tablet",     _("Tablet")],
+                                     ["touch",     _("Touch")],
                                      ["fullscale", _("Full scale")],
                                      ["scan",      _("Scanning")]]
 
             widget = GSettingsComboBox(_("Keyboard layout"), "org.cinnamon.keyboard", "keyboard-type", keyboard_type_options)
             settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
 
+            keyboard_position_options = [["bottom",     _("At the bottom of the screen")],
+                                         ["top",     _("At the top of the screen")]]
+            widget = GSettingsComboBox(_("Keyboard position"), "org.cinnamon.keyboard", "keyboard-position", keyboard_position_options)
+            settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
+
+            keyboard_size_options = [[4,     _("A quarter of the screen")],
+                                     [3,     _("A third of the screen")],
+                                     [2, _("Half of the screen")]]
+
+            widget = GSettingsComboBox(_("Keyboard size"), "org.cinnamon.keyboard", "keyboard-size", keyboard_size_options)
+            settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
+
             activation_mode_options = [["accessible", _("Show the keyboard any time something expects input")],
                                        ["on-demand",  _("Show keyboard only when the user activates it")]];
 
@@ -470,5 +492,3 @@ class Module:
             ret = self.iface_settings.get_default_value(KEY_TEXT_SCALING_FACTOR).get_double()
 
         return ret
-
-
